package com.jiuqi.util.chinese;

import java.io.Serializable;
import java.util.ArrayList;

/* loaded from: com_jiuqi_util_chinese.jar:com/jiuqi/util/chinese/ChineseInt.class */
public class ChineseInt implements Cloneable, Serializable {
    private static final char[] INVALID_CHARS = {' ', 12288};
    private String intValue;

    public ChineseInt() {
        this.intValue = "0";
    }

    public ChineseInt(long value) {
        this.intValue = String.valueOf(value);
    }

    public ChineseInt(String value) {
        if (isIntString(value)) {
            this.intValue = value;
            return;
        }
        try {
            this.intValue = valueOf(value);
        } catch (Exception unused) {
            this.intValue = "0";
        }
    }

    public long longValue() {
        return Long.parseLong(this.intValue);
    }

    public String chineseValue(boolean showUnit, boolean useBigChar) {
        return parseToChinese(this.intValue, showUnit, useBigChar);
    }

    public static String valueOf(String value) throws NotValidChineseNumberException, NoValidCharException {
        boolean negtive = false;
        StringSplitor chars = new StringSplitor(value, INVALID_CHARS);
        char thisChar = chars.getNextValidChar();
        if (thisChar == '(' || thisChar == 65288) {
            if (chars.getNextValidChar() == 36127) {
                char thisChar2 = chars.getNextValidChar();
                if (thisChar2 == ')' || thisChar2 == 65289) {
                    negtive = true;
                } else {
                    throw new NotValidChineseNumberException("字符'负'后面的字符无效，必须是')'！");
                }
            } else {
                throw new NotValidChineseNumberException("字符'('后面的字符无效，必须是'负'！");
            }
        }
        if (!negtive) {
            chars.rollBack();
        }
        boolean hasUnit = false;
        char thisChar3 = chars.getNextValidChar();
        if (ChineseDigit.isValidChineseDigit(thisChar3)) {
            if (ChineseDigitUnit.isValidChineseDigitUnit(String.valueOf(chars.getNextValidChar()))) {
                hasUnit = true;
            }
            chars.rollBack();
            chars.rollBack();
            long longValue = 0;
            if (hasUnit) {
                int tempValue = 0;
                while (chars.hasValidChar()) {
                    char thisChar4 = chars.getNextValidChar();
                    if (ChineseDigit.isValidChineseDigit(thisChar4)) {
                        try {
                            tempValue = ChineseDigit.valueOf(thisChar4);
                            if (!chars.hasValidChar()) {
                                longValue += tempValue;
                            }
                        } catch (NotValidChineseDigitException unused) {
                            throw new NotValidChineseNumberException("存在非法字符\"" + thisChar4 + "\"！");
                        }
                    } else if (ChineseDigitUnit.isValidChineseDigitUnit(String.valueOf(thisChar4))) {
                        if (ChineseDigitUnit.isLargeUnit(thisChar4)) {
                            long longValue2 = longValue + tempValue;
                            tempValue = 0;
                            try {
                                longValue = longValue2 * Long.parseLong(ChineseDigitUnit.valueOf(String.valueOf(thisChar4)));
                            } catch (NotValidChineseDigitUnitException unused2) {
                                throw new NotValidChineseNumberException("存在非法字符\"" + thisChar4 + "\"！");
                            }
                        } else {
                            try {
                                longValue += tempValue * Long.parseLong(ChineseDigitUnit.valueOf(String.valueOf(thisChar4)));
                                tempValue = 0;
                            } catch (NotValidChineseDigitUnitException unused3) {
                                throw new NotValidChineseNumberException("存在非法字符\"" + thisChar4 + "\"！");
                            }
                        }
                    } else {
                        throw new NotValidChineseNumberException("存在非法的字符\"" + thisChar4 + "\"！");
                    }
                }
            } else {
                StringBuffer stringValue = new StringBuffer();
                while (chars.hasValidChar()) {
                    char thisChar5 = chars.getNextValidChar();
                    if (ChineseDigit.isValidChineseDigit(thisChar5)) {
                        try {
                            stringValue.append(ChineseDigit.valueOf(thisChar5));
                        } catch (NotValidChineseDigitException unused4) {
                            throw new NotValidChineseNumberException("存在非法字符\"" + thisChar5 + "\"！");
                        }
                    }
                }
                longValue = Long.parseLong(stringValue.toString());
            }
            if (negtive) {
                longValue = -longValue;
            }
            return String.valueOf(longValue);
        }
        throw new NotValidChineseNumberException("开头的字符\"" + thisChar3 + "\"不是数字！");
    }

    public static String parseToChinese(String value, boolean showUnit, boolean useBigChar) {
        if (value != null && !value.equals("") && isIntString(value)) {
            boolean negative = false;
            if (value.startsWith("-")) {
                negative = true;
                value = value.substring(1);
            }
            ArrayList digits = new ArrayList();
            for (int i = 0; i < value.length(); i++) {
                int digit = value.charAt(i) - '0';
                if (digit >= 0 && digit <= 9) {
                    digits.add(new Integer(digit));
                }
            }
            StringBuffer result = new StringBuffer();
            if (!showUnit) {
                for (int i2 = 0; i2 < digits.size(); i2++) {
                    result.append(ChineseDigit.toChineseChar(((Integer) digits.get(i2)).intValue(), useBigChar));
                }
            } else {
                int cursor = digits.size();
                int i3 = 0;
                while (cursor >= 0) {
                    int smallInt = getSmallInt(digits, i3);
                    if (smallInt != 0) {
                        result.insert(0, String.valueOf(smallIntToChineseString(smallInt, useBigChar)) + ChineseDigitUnit.toChineseUnit(getUnit(i3 * 4), useBigChar));
                    }
                    cursor -= 4;
                    if (smallInt < 1000 && smallInt > 0 && cursor >= 0) {
                        result.insert(0, ChineseDigit.toChineseChar(0, useBigChar));
                    }
                    i3++;
                }
            }
            if (negative) {
                result.insert(0, "(负)");
            }
            return result.toString();
        }
        throw new IllegalArgumentException("字符串\"" + value + "\"不是合法的阿拉伯数字字符串！");
    }

    private static int getSmallInt(ArrayList digits, int i) {
        int value = 0;
        int cursor = (digits.size() - (i * 4)) - 1;
        for (int j = 0; j < 4 && cursor >= 0; j++) {
            int digit = ((Integer) digits.get(cursor)).intValue();
            value = (int) (value + (digit * Math.pow(10.0d, j)));
            cursor--;
        }
        return value;
    }

    private static String smallIntToChineseString(int value, boolean useBigChar) {
        if (value >= 0 && value < 10000) {
            int[] digits = new int[4];
            int count = 3;
            while (value != 0) {
                digits[count] = value % 10;
                value /= 10;
                count--;
            }
            StringBuffer result = new StringBuffer();
            boolean allZeroBefore = true;
            boolean zeroExist = false;
            for (int i = 0; i < digits.length; i++) {
                if (digits[i] != 0) {
                    result.append(String.valueOf(ChineseDigit.toChineseChar(digits[i], useBigChar)) + ChineseDigitUnit.toChineseUnit(getUnit(3 - i), useBigChar));
                    allZeroBefore = false;
                    zeroExist = false;
                } else if (!allZeroBefore) {
                    boolean allZeroAfter = true;
                    int j = i + 1;
                    while (true) {
                        if (j >= 4) {
                            break;
                        }
                        if (digits[j] == 0) {
                            j++;
                        } else {
                            allZeroAfter = false;
                            break;
                        }
                    }
                    if (!allZeroAfter && !zeroExist) {
                        result.append(ChineseDigit.toChineseChar(0, useBigChar));
                        zeroExist = true;
                    }
                }
            }
            return result.toString();
        }
        throw new IllegalArgumentException("只能解析0-9999的整数");
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static boolean isIntString(String value) {
        if (value.startsWith("-")) {
            value = value.substring(1);
        }
        return ChineseDigitUnit.isDigitString(value);
    }

    private static String getUnit(int i) {
        StringBuffer sb = new StringBuffer("1");
        for (int j = 0; j < i; j++) {
            sb.append("0");
        }
        return sb.toString();
    }

    public Object clone() {
        return new ChineseInt(this.intValue);
    }

    public boolean equals(Object o) {
        if (o == this) {
            return true;
        }
        if (!(o instanceof ChineseInt)) {
            return false;
        }
        ChineseInt value = (ChineseInt) o;
        return this.intValue.equals(value.intValue);
    }

    public int hashCode() {
        int result = super.hashCode();
        if (this.intValue != null) {
            result ^= this.intValue.hashCode();
        }
        return result;
    }

    public String toString() {
        return chineseValue(true, false);
    }
}
